# sha256sum
Compute SHA256 message digest from a file.

[![CI](https://github.com/oittaa/sha256sum/actions/workflows/main.yml/badge.svg)](https://github.com/oittaa/sha256sum/actions/workflows/main.yml)
[![codecov](https://codecov.io/gh/oittaa/sha256sum/branch/main/graph/badge.svg?token=9J5X0UDEP3)](https://codecov.io/gh/oittaa/sha256sum)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Install

```
pip install sha256sum
```

## Usage

```
from sha256sum import sha256sum

output = sha256sum("/path/to/file")
```
